How to release conu
===================

We are using awesome `release-bot <(https://github.com/user-cont/release-bot>`_ for new conu releases.
If you want to make new release:
    - create new issue in Github upstream repository with title ``x.y.z release`` and wait for release bot to create new PR.
    - **polish CHANGELOG.md** and merge if tests are passing.
    - Sit down, relax and watch how release bot is doing the hard work.

